@@ -10,7 +10,7 @@ def test_login(username, password, domain):
     headers = {'authority': "api.askdata.com",
                'accept': "application/json, text/plain, */*",
                'accept-language': "it-IT,it;q=0.9,en-US;q=0.8,en;q=0.7,ar;q=0.6",
-               'authorization': "Basic c21hcnRhZ2VudDpzbWFydGFnZW50", 'content-type': "application/x-www-form-urlencoded", 
+               'authorization': "Basic YXNrZGF0YS1zZGs6YXNrZGF0YS1zZGs=", 'content-type': "application/x-www-form-urlencoded", 
                'origin': "https://app.askdata.com",
                'referer': "https://app.askdata.com/",
                'sec-ch-ua-mobile': "?1",
@@ -292,7 +292,9 @@ def run_test(query = '',
         
     except AssertionError:
     
-        message_body += "<br><b style='color:red;'>Test Failed</b> for query: {}".format(query)
+        status = response.status_code
+    
+        message_body += "<br><b style='color:red;'>Test Failed</b> Reponse status {} for query: {}".format(status, query)
     
         test_failed += 1
         
